@@ -1,39 +1,85 @@
 OC.L10N.register(
     "calendar",
     {
+    "Provided email-address is too long" : "Alamat surel yang diberikan terlalu panjang",
+    "User-Session unexpectedly expired" : "Sesi-Pengguna kedaluwarsa secara tidak terduga",
     "Provided email-address is not valid" : "Alamat surel tidak valid",
     "%s has published the calendar »%s«" : "%s telah mempublikasikan kalender »%s«",
     "Unexpected error sending email. Please contact your administrator." : "Galat saat mengirim surel. Silakan hubungi administrator Anda.",
+    "Successfully sent email to %1$s" : "Berhasil mengirim surel ke %1$s",
     "Hello," : "Halo,",
     "We wanted to inform you that %s has published the calendar »%s«." : "Kami ingin menginformasikan Anda bahwa %s telah mempublikasikan kalender »%s«.",
     "Open »%s«" : "Buka »%s«",
     "Cheers!" : "Horee!",
+    "Upcoming events" : "Acara mendatang",
+    "More events" : "Lebih banyak acara",
+    "No more events today" : "Tidak ada acara lagi hari ini",
+    "No upcoming events" : "Tdak ada acara mendatang",
+    "%1$s with %2$s" : "%1$sdengan %2$s",
     "Calendar" : "Kalender",
+    "New booking {booking}" : "Pemesanan baru (pemesanan)",
+    "{display_name} ({email}) booked the appointment \"{config_display_name}\" on {date_time}." : "{display_name} ({email}) memesan janji temu \"{config_display_name}\" pada {date_time}.",
+    "Appointments" : "Janji temu",
+    "Schedule appointment \"%s\"" : "Jadwalkan janji temu \"%s\"",
+    "Schedule an appointment" : "Jadwalkan janji temu",
+    "Prepare for %s" : "Bersiaplah untuk %s",
+    "Your appointment \"%s\" with %s needs confirmation" : "Janji temu Anda \"%s\" dengan %s membutuhkan konfirmasi ",
+    "Dear %s, please confirm your booking" : "Kepada %s, mohon konfirmasi pemesanan Anda",
     "Confirm" : "Konfirmasi",
+    "This confirmation link expires in %s hours." : "Tautan konfirmasi ini akan kedaluwarsa dalam %s jam.",
+    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Jika Anda ingin membatalkan janji temu, mohon hubungi penyelenggara Anda dengan membalas surel ini atau mengunjungi halaman profil mereka",
+    "Your appointment \"%s\" with %s has been accepted" : "Janji temu \"%s\" dengan %stelah diterima",
+    "Dear %s, your booking has been accepted." : "Kepada %s, pemesanan Anda telah diterima.",
+    "Appointment for:" : "Janji temu untuk:",
+    "Date:" : "Tanggal:",
+    "You will receive a link with the confirmation email" : "Anda akan menerima tautan dengan surel konfirmasi",
+    "Where:" : "Tempat:",
+    "Comment:" : "Komentar:",
+    "You have a new appointment booking \"%s\" from %s" : "Anda memiliki pemesanan janji temu baru \"%s\" dari %s",
+    "Dear %s, %s (%s) booked an appointment with you." : "Kepada %s, %s (%s) memesan janji temu dengan Anda.",
     "A Calendar app for Nextcloud" : "Aplikasi Kalender untuk Nextcloud",
     "Previous day" : "Hari sebelum",
     "Previous week" : "Minggu sebelum",
+    "Previous year" : "Tahun lalu",
     "Previous month" : "Bulan sebelum",
     "Next day" : "Hari setelah",
     "Next week" : "Minggu setelah",
+    "Next year" : "Tahun depan",
     "Next month" : "Bulan setelah",
+    "Event" : "Acara",
+    "Create new event" : "Buat acara baru",
     "Today" : "Hari Ini",
     "Day" : "Hari",
     "Week" : "Minggu",
     "Month" : "Bulan",
+    "Year" : "Tahun",
+    "List" : "daftar",
     "Preview" : "Pratinjau",
     "Copy link" : "Salin tautan",
     "Edit" : "Sunting",
     "Delete" : "Hapus",
+    "Appointment link was copied to clipboard" : "Tautan janji temu disalin ke papan klip",
+    "Appointment link could not be copied to clipboard" : "Tautan janji temu tidak dapat disalin ke papan klip",
+    "Add new" : "Tambahkan baru",
     "Untitled calendar" : "Kalender tanpa judul",
+    "Shared with you by" : "Dibagikan dengan Anda oleh",
+    "Edit and share calendar" : "Edit dan bagikan kalender",
+    "Edit calendar" : "Edit kalender",
+    "Disable calendar \"{calendar}\"" : "Nonaktifkan kalender \"{calendar}\"",
+    "Disable untitled calendar" : "Nonaktifkan kalender tanpa judul",
+    "Enable calendar \"{calendar}\"" : "Aktifkan kalender \"{calendar}\"",
+    "Enable untitled calendar" : "Aktifkan kalender tanpa judul",
     "An error occurred, unable to change visibility of the calendar." : "Terjadi galat, tidak dapat mengubah visibilitas kalender.",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Batal berbagi kalender dalam {countdown} detik"],
     "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Menghapus kalender dalam {countdown} detik"],
     "New calendar" : "Kalender baru",
+    "Name for new calendar" : "Nama untuk kalender baru",
     "Creating calendar …" : "Membuat kalender …",
     "New calendar with task list" : "Kalender baru dengan daftar tugas",
     "New subscription from link (read-only)" : "Langganan baru dengan tautan (baca-saja)",
     "Creating subscription …" : "Membuat langganan …",
+    "Add public holiday calendar" : "Tambahkan kalender hari libur nasional",
+    "Add custom public calendar" : "Tambahkan kalender publik khusus",
     "An error occurred, unable to create the calendar." : "Terjadi galat, tidak dapat membuat kalender.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Silakan isi tautan valid (dimulai dengan http://, https://, webcal://, or webcals://)",
     "Copy subscription link" : "Salin tautan berlangganan",
@@ -43,11 +89,21 @@ OC.L10N.register(
     "Export" : "Ekspor",
     "Calendar link copied to clipboard." : "Tautan kalender disalin ke papan klip.",
     "Calendar link could not be copied to clipboard." : "Tautan kalender tidak dapat disalin ke papan klip.",
+    "Trash bin" : "Keranjang sampah",
+    "Loading deleted items." : "Memuat item yang dihapus.",
+    "You do not have any deleted items." : "Anda tidak memiliki item yang dihapus.",
     "Name" : "Nama",
     "Deleted" : "Dihapus",
     "Restore" : "Pulihkan",
     "Delete permanently" : "Hapus secara permanen",
     "Empty trash bin" : "Kosongkan tempat sampah",
+    "Untitled item" : "Item tanpa judul",
+    "Unknown calendar" : "Kalender tidak diketahui",
+    "Could not load deleted calendars and objects" : "Tidak dapat memuat kalender dan objek yang dihapus",
+    "Could not restore calendar or event" : "Tidak dapat memulihkan kalender atau acara",
+    "Do you really want to empty the trash bin?" : "Apakah Anda benar-benar ingin mengosongkan keranjang sampah?",
+    "_Items in the trash bin are deleted after {numDays} day_::_Items in the trash bin are deleted after {numDays} days_" : ["Item dalam keranjang sampah dihapus setelah {numDays} hari"],
+    "Could not update calendar order." : "Tidak dapat membarui urutan kalender.",
     "Share link" : "Bagikan tautan",
     "Copy public link" : "Salin tautan publik",
     "Send link to calendar via email" : "Kirim tautan kalender via surel",
@@ -65,6 +121,7 @@ OC.L10N.register(
     "Unpublishing calendar failed" : "Gagal membatalkan penerbitan kalender",
     "can edit" : "dapat edit",
     "Unshare with {displayName}" : "Batal berbagi dengan {displayName}",
+    "An error occurred while unsharing the calendar." : "Terjadi kesalahan saat membatalkan pembagian kalender. ",
     "An error occurred, unable to change the permission of the share." : "Terjadi galat, tidak dapat mengubah hak akses berbagi.",
     "Share with users or groups" : "Berbagi dengan pengguna atau grup",
     "No users or groups" : "Tidak ada pengguna atau grup",
@@ -74,6 +131,8 @@ OC.L10N.register(
     "Cancel" : "Batal",
     "_Import calendar_::_Import calendars_" : ["Impor kalender"],
     "Invalid location selected" : "Lokasi yang tidak valid dipilih",
+    "Attachments folder successfully saved." : "Folder lampiran berhasil disimpan.",
+    "Error on saving attachments folder." : "Kesalahan saat menyimpan folder lampiran.",
     "No valid files found, aborting import" : "Berkas valid tidak ditemukan, impor dibatalkan",
     "Import partially failed. Imported {accepted} out of {total}." : "Sebagian impor gagal. Dari {total} hanya {accepted} berhasil impor.",
     "Automatic" : "Otomatis",
@@ -102,6 +161,7 @@ OC.L10N.register(
     "Show keyboard shortcuts" : "Tampilkan pintasan papan kunci",
     "CalDAV link copied to clipboard." : "Tautan CalDAV disalin ke papan klip",
     "CalDAV link could not be copied to clipboard." : "Tautan CalDAV tidak dapat disalin ke papan klip",
+    "To configure appointments, add your email address in personal settings." : "Untuk mengonfigurasi janji temu, tambahkan alamat surel Anda di pengaturan pribadi.",
     "Location" : "Lokasi",
     "Description" : "Deskrisi",
     "to" : "untuk",
@@ -114,7 +174,9 @@ OC.L10N.register(
     "Saturday" : "Sabtu",
     "Sunday" : "Minggu",
     "Update" : "Perbarui",
+    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Kami telah mengirim surel dengan detailnya. Mohon konfirmasikan janji temu Anda menggunakan tautan dalam surel tersebut. Anda dapat menutup halaman ini sekarang.",
     "Your email address" : "Alamat surel Anda",
+    "Could not book the appointment. Please try again later or contact the organizer." : "Tidak dapat memesan janji temu. Mohon coba lagi nanti atau hubungi penyelenggara.",
     "Notification" : "Notifikasi",
     "Email" : "Surel",
     "Audio notification" : "Notifikasi audio",
@@ -134,7 +196,9 @@ OC.L10N.register(
     "_week_::_weeks_" : ["minggu"],
     "Delete file" : "Hapus berkas",
     "Choose a file to add as attachment" : "Pilih berkas untuk ditambahkan sebagai lampiran",
+    "Not available" : "Tidak tersedia",
     "Availability of attendees, resources and rooms" : "Ketersediaan peserta, sumber daya, dan ruangan",
+    "Done" : "Selesai",
     "Free" : "Luang",
     "Busy (tentative)" : "Sibuk (tentatif)",
     "Busy" : "Sibuk",
@@ -143,34 +207,44 @@ OC.L10N.register(
     "Accept" : "Terima",
     "Decline" : "Tolak",
     "Tentative" : "Tentatif",
+    "The invitation has been accepted successfully." : "Undangan berhasil diterima.",
+    "Failed to accept the invitation." : "Gagal menerima undangan.",
+    "The invitation has been declined successfully." : "Undangan berhasil ditolak.",
+    "Failed to decline the invitation." : "Gagal menolak undangan.",
+    "Your participation has been marked as tentative." : "Partisipasi Anda telah ditandai sebagai belum pasti.",
+    "Failed to set the participation status to tentative." : "Gagal menyetel status partisipasi menjadi belum pasti.",
+    "Attendees" : "Peserta",
     "Create Talk room for this event" : "Buat ruangan Talk untuk acara ini",
-    "Show busy times" : "Tampilkan waktu sibuk",
     "No attendees yet" : "Belum ada peserta",
     "Successfully appended link to talk room to description." : "Berhasil menambahkan tautan ruang Talk pada deskripsi.",
     "Error creating Talk room" : "Galat membuat ruangan Talk",
-    "Send email" : "Kirim surel",
     "Required participant" : "Partisipan wajib",
     "Optional participant" : "Partisipan opsional",
     "Non-participant" : "Bukan partisipan",
     "Remove group" : "Hapus grup",
     "Remove attendee" : "Hapus peserta",
     "No match found" : "Tidak ditemukan kecocokan",
+    "Note that members of circles get invited but are not synced yet." : "Perhatikan bahwa anggota kelompok diundang tapi belum tersinkronisasi.",
     "(organizer)" : "(penyelenggara)",
+    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Untuk mengirim undangan dan mengurus respons, [linkopen]tambahkan alamat surel Anda di pengaturan pribadi[linkclose].",
     "Remove color" : "Hapus warna",
     "Event title" : "Judul acara",
     "All day" : "Sepanjang hari",
+    "Cannot modify all-day setting for events that are part of a recurrence-set." : "Tidak dapat mengubah pengaturan sehari penuh untuk acara yang merupakan bagian dari set pengulangan.",
     "Repeat" : "Ulang",
     "End repeat" : "Akhiri perulangan",
     "Select to end repeat" : "Pilih untuk mengakhiri perulangan",
     "never" : "tidak pernah",
     "on date" : "pada tanggal",
     "after" : "setelah",
+    "This event is the recurrence-exception of a recurrence-set. You cannot add a recurrence-rule to it." : "Acara ini merupakan pengecualian pengulangan dari set pengulangan. Anda tidak dapat menambahkan aturan pengulangan pada acara ini.",
     "first" : "pertama",
     "third" : "ke-3",
     "fourth" : "ke-4",
     "fifth" : "ke-5",
     "second to last" : "kedua terakhir",
     "last" : "terakhir",
+    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Perubahan pada aturan pengulangan hanya akan diterapkan untuk acara ini dan semua acara selanjutnya.",
     "Repeat every" : "Ulang setiap",
     "By day of the month" : "Berdasarkan hari pada bulan",
     "On the" : "Pada",
@@ -179,21 +253,28 @@ OC.L10N.register(
     "weekday" : "akhir pekan",
     "weekend day" : "akhir pekan",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Penentuan perulangan acara ini tidak sepenuhnya didukung oleh Nextcloud. Jika Anda mengedit opsi pengulangan, pengulangan tertentu mungkin hilang.",
-    "More" : "Lainnya",
     "Public calendar does not exist" : "Kalender publik tidak eksis",
     "Maybe the share was deleted or has expired?" : "Mungkin yang dibagikan terhapus atau kadaluwarsa?",
     "Pick a time" : "Pilih waktu",
     "Pick a date" : "Pilih tanggal",
     "Please enter a valid date" : "Silakan isi tanggal valid",
     "Please enter a valid date and time" : "Silakan isi tanggal dan waktu valid",
+    "Speak to the server administrator to resolve this issue." : "Hubungi administrator server untuk menyelesaikan masalah ini.",
+    "Public holiday calendars are provided by Thunderbird. Calendar data will be downloaded from {website}" : "Kalender hari libur nasional disediakan oleh Thunderbird. Data kalender akan diunduh dari {website}",
+    "These public calendars are suggested by the sever administrator. Calendar data will be downloaded from the respective website." : "Kalender-kalender umum ini disarankan oleh administrator server. data Kalender akan diunduh dari situs web masing-masing.",
     "Subscribe" : "Berlangganan",
+    "An error occurred, unable to read public calendars." : "Terjadi kesalahan, tidak dapat membaca kalender umum.",
+    "An error occurred, unable to subscribe to calendar." : "Terjadi kesalahan, tidak dapat berlangganan kalender.",
+    "Thank you. Your booking from {startDate} to {endDate} has been confirmed." : "Terima kasih. Pemesanan Anda dari {startDate} hingga  {endDate} telah dikonfirmasi.",
+    "The slot for your appointment from {startDate} to {endDate} is not available any more." : "Slot untuk janji temu Anda dari {startDate} hingga {endDate} tidak lagi tersedia.",
     "Personal" : "Pribadi",
+    "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Deteksi zona waktu otomatis menetapkan UTC sebagai zona waktu Anda. Hal ini kemungkinan besar disebabkan oleh langkah keamanan peramban web Anda. Harap setel zona waktu Anda secara manual di pengaturan kalender.",
+    "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Zona waktu Anda yang terkonfigurasi ({timezoneId}) tidak ditemukan. Kembali ke UTC.\nHarap ubah zona waktu Anda di pengaturan dan laporkan masalah ini.",
     "[Today]" : "[Hari ini]",
     "Details" : "Detail",
-    "Attendees" : "Peserta",
     "Resources" : "Sumber daya",
     "Close" : "Tutup",
-    "Show more details" : "Tampilkan detail lain",
+    "Untitled event" : "Acara tanpa judul",
     "Subscribe to {name}" : "Berlangganan ke {name}",
     "Anniversary" : "Hari jadi",
     "Appointment" : "Janji",
@@ -234,11 +315,11 @@ OC.L10N.register(
     "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["pada hari {dayOfMonthList}"],
     "until {untilDate}" : "sampai {untilDate}",
     "_%n time_::_%n times_" : ["%n kali"],
-    "Untitled event" : "Acara tanpa judul",
     "Untitled task" : "Tugas tanpa judul",
     "Please ask your administrator to enable the Tasks App." : "Silakan tanya administrator Anda untuk mengaktifkan aplikasi Tugas.",
     "_+%n more_::_+%n more_" : ["+%n lagi"],
     "Other" : "Lainnya",
+    "The visibility of this event in shared calendars." : "Visibilitas acara ini di kalender yang dibagikan.",
     "Add a location" : "Tambah lokasi",
     "Add a description" : "Tambah deskripsi",
     "Status" : "Status",
@@ -254,9 +335,6 @@ OC.L10N.register(
     "Special color of this event. Overrides the calendar-color." : "Warna spesial dari acara ini. Mengganti warna kalender.",
     "Chat room for event" : "Ruang obrolan untuk acara",
     "An error occurred, unable to delete the calendar." : "Terjadi galat, tidak dapat menghapus kalender.",
-    "Talk" : "Talk",
-    "Review" : "Tinjauan",
-    "Mail" : "Surel",
-    "Birthday" : "Tanggal lahir"
+    "This is an event reminder." : "Ini adalah pengingat acara."
 },
 "nplurals=1; plural=0;");
